@@ -13,7 +13,7 @@ import logging
 # from twisted.internet import defer, reactor
 from twisted.internet import defer
 from twisted.internet.error import ConnectionRefusedError
-
+from w3lib.http import basic_auth_header
 from scrapy import signals
 from scrapy.http import TextResponse
 from scrapy.core.downloader.handlers.http11 import TunnelError, TimeoutError
@@ -30,6 +30,7 @@ class Proxy(object):
         self.ip_data = 0
         try:
             proxy = spider.proxy
+            self.proxy_name = proxy.get('name'),
             self.proxies = ProxyGetter(
                 proxy.get('url'),
                 proxy.get('name'),
@@ -94,6 +95,11 @@ class Proxy(object):
                 ip_raw = random.choice(self.ip_list)
                 self.ip_list.remove(ip_raw)
                 request.meta["proxy"] = ip_raw
+                if self.proxy_name is 'kuaidaili_ip':
+                    request.headers['Proxy-Authorization'] = basic_auth_header(
+                        '${username}', '${password}'
+                    )
+                    request.headers["Connection"] = "close"
             else:
                 logging.info('代理列表为空')
 
