@@ -79,8 +79,8 @@ class ProxyGetter(metaclass=ProxyMeta):
                 return res
             for proxy in res:
                 proxies.append(proxy)
-        except:
-            pass
+        except Exception as e:
+            print(f"{self.name}:{e}")
         if proxies:
             return proxies
 
@@ -143,6 +143,19 @@ class ProxyGetter(metaclass=ProxyMeta):
     def zhima_ip(self):
         pass
 
+    @stat_called_time
+    def kuaidaili_ip(self):
+        # https://tps.kdlapi.com/api/gettps/?orderid=903884027633888&num=1&pt=1&format=json&sep=1
+        # https://dev.kdlapi.com/api/setipwhitelist?orderid=903884027633888&iplist=%s&signature=thl1n7lqhisfikvznxwl631bds413640
+        ip_list = []
+        res = json.loads(requests.get(self.url).text)
+        for item in res.get("data").get("proxy_list"):
+            ip_list.append(f"https://{item}")
+        if ip_list:
+            return ip_list
+        else:
+            return res
+
     @stat_called_time
     def source_proxy(self):
         res = json.loads(requests.get(self.url).text)
@@ -160,3 +173,11 @@ class ProxyGetter(metaclass=ProxyMeta):
             return res.get("data")
         else:
             return res
+
+# if __name__ == '__main__':
+#     print(ProxyGetter(
+#         'https://tps.kdlapi.com/api/gettps/?orderid=903884027633888&num=1&pt=1&format=json&sep=1',
+#         'kuaidaili_ip',
+#         add_whitelist='https://dev.kdlapi.com/api/setipwhitelist?orderid=903884027633888&iplist=%s&signature=thl1n7lqhisfikvznxwl631bds413640',
+#         # del_whitelist=proxy.get('del_whitelist')
+#     ).get_proxies())
